@@ -6,7 +6,7 @@ use v5.10.1;
 use strict;
 use warnings;
 
-our $VERSION = 'v0.1.1';
+our $VERSION = 'v0.1.2';
 
 use parent qw/ Plack::Component /;
 
@@ -44,7 +44,6 @@ sub prepare_app {
         $self->request(
             [
              qw/
-             User-Agent
              X-Forwarded-For
              X-Forwarded-Host
              X-Forwarded-Port
@@ -108,6 +107,9 @@ sub call {
             my $value = $req_head->header($field) // next;
             $mech->add_header( $field => $value );
         }
+        if (my $ua = $req_head->header('User-Agent')) {
+            $mech->add_header( 'X-Forwarded-User-Agent' => $ua );
+        }
 
         my $res  = $mech->get( $url );
 
@@ -132,6 +134,9 @@ sub call {
             my $age;
             if (my $value = $head->header("Cache-Control")) {
                 ($age) = $value =~ /(?:s\-)?max-age=([0-9]+)\b/;
+                if ($age && $age > $self->max_age) {
+                    $age = $self->max_age;
+                }
             }
 
             $data = [ HTTP_OK, $h->headers, [$body] ];
@@ -165,7 +170,7 @@ Plack::App::Prerender - a simple prerendering proxy for Plack
 
 =head1 VERSION
 
-version v0.1.1
+version v0.1.2
 
 =head1 SYNOPSIS
 
@@ -248,12 +253,36 @@ used instead.
 =head2 request
 
 This is an array reference of request headers to pass through the
-proxy.
+proxy.  These default to the reverse proxy forwarding headers:
+
+=over
+
+=item C<X-Forwarded-For>
+
+=item C<X-Forwarded-Host>
+
+=item C<X-Forwarded-Port>
+
+=item C<X-Forwarded-Proto>
+
+=back
+
+The C<User-Agent> is forwarded as C<X-Forwarded-User-Agent>.
 
 =head2 response
 
 This is an array reference of response headers to pass from the
-result.
+result.  It defaults to the following headers:
+
+=over
+
+=item C<Content-Type>
+
+=item C<Expires>
+
+=item C<Last-Modified>
+
+=back
 
 =head2 wait
 
